@@ -284,7 +284,7 @@ class ComputeDataService(ComputeDataService):
                     pj=self._schedule_cu(cu) 
                     if pj !=None:
                         cu = self.__expand_working_directory(cu, pj)                        
-                        pj._submit_cu(cu)           
+                        pj.submit_cu(cu)           
                         self.cu_queue.task_done()         
                     else:
                         self.cu_queue.task_done() 
@@ -371,14 +371,16 @@ class ComputeUnit(ComputeUnit):
     """ ComputeUnit - Wrapper for BigJob subjob """
     CU_ID_PREFIX="cu-"  
 
-    def __init__(self, compute_unit_description, work_data_service):
+    def __init__(self, compute_unit_description, work_data_service=None):
         self.id = self.CU_ID_PREFIX + str(uuid.uuid1())
-        self.url = work_data_service.url + "/" + self.id
+        if work_data_service!=None:
+            self.url = work_data_service.url + "/" + self.id
+            logger.debug("Created CU: %s"%self.url)  
         self.state = State.New       
         self.subjob = None # reference to BigJob Subjob 
-        self.compute_unit_description = compute_unit_description # WU Description
+        self.compute_unit_description = compute_unit_description # CU Description
         self.subjob_description = self.__translate_cu_sj_description(compute_unit_description)
-        logger.debug("Created CU: %s"%self.url)     
+           
                 
     def get_id(self):
         return self.id
